/**
 * A set that can be listened to for when it changes.
 */
interface LiveSet<T> extends Iterable<T> {
    /**
     * Should call the provided listener whenever the composition of items in the set changes.
     */
    addEventListener(name: 'change', listener: () => void): void;
}
/**
 * A live collection of SVG element highlightings.
 *
 * The highlightings will auto-update in response to any changes in the set of target SVG elements
 * or in the parent SVG document that the target SVG elements are contained in.
 *
 * The underlying DOM nodes that make up SVG element highlightings are not meant to be directly edited
 * by outside code.
 */
export declare class LiveSVGElementHighlightings {
    private targetSVGElements;
    /**
     * The actual DOM node that contains all of the underlying DOM nodes that make up the SVG element highlightings.
     */
    private domNode;
    /**
     * Use box highlightings to highlight the bounding boxes of the target SVG elements.
     */
    private boxHighlightings;
    private parentSVGDocCoordinateSystem;
    /**
     * The target SVG elements must all have a bounding box.
     *
     * (SVG graphics elements are the only kind of element that a user would usually interact with anyways.)
     *
     * @param targetSVGElements The SVG elements to highlight.
     * @param parentSVGDoc The SVG document that the target SVG elements are contained in.
     */
    constructor(targetSVGElements: LiveSet<SVGGraphicsElement>, parentSVGDoc: SVGSVGElement);
    /**
     * Appends the SVG element highlightings to the provided container node
     * (such as another SVG document that has been overlaid over the parent SVG document
     * that the target SVG elements are contained in).
     */
    appendTo(container: Node): void;
    /**
     * Removes the SVG element highlightings from whatever parent container node that they are in.
     *
     * Has no effect if the SVG element highlightings did not have a parent container node to begin with.
     */
    remove(): void;
    private refresh;
}
export {};
//# sourceMappingURL=LiveSVGElementHighlightings.d.ts.map